@@ -1,12 +1,8 @@
 from botocore import UNSIGNED, translate
 from botocore.exceptions import PartialCredentialsError
-from botocore.session import (
-    EVENT_ALIASES,
-    ServiceModel,
-    Session,
-    UnknownServiceError,
-    copy,
-)
+from botocore.session import EVENT_ALIASES, ServiceModel
+from botocore.session import Session as _SyncSession
+from botocore.session import UnknownServiceError, copy
 
 from . import retryhandler
 from .client import AioBaseClient, AioClientCreator
@@ -31,8 +27,7 @@ class ClientCreatorContext:
         await self._client.__aexit__(exc_type, exc_val, exc_tb)
 
 
-class AioSession(Session):
-
+class AioSession(_SyncSession):
     # noinspection PyMissingConstructor
     def __init__(
         self,
@@ -80,11 +75,9 @@ class AioSession(Session):
 
     async def get_credentials(self):
         if self._credentials is None:
-            self._credentials = await (
-                self._components.get_component(
-                    'credential_provider'
-                ).load_credentials()
-            )
+            self._credentials = await self._components.get_component(
+                'credential_provider'
+            ).load_credentials()
         return self._credentials
 
     async def get_service_model(self, service_name, api_version=None):
@@ -126,7 +119,6 @@ class AioSession(Session):
         aws_session_token=None,
         config=None,
     ):
-
         default_client_config = self.get_default_client_config()
         # If a config is provided and a default config is set, then
         # use the config resulting from merging the two.
